@@ -19,8 +19,8 @@ class High_Level:
 	def __init__(self, parent: "NovelAI_API"):
 		self._parent = parent
 
-		for filename in listdir("schemas"):
-			with open(join("schemas", filename)) as f:
+		for filename in listdir(join(self._parent._lib_root, "schemas")):
+			with open(join(self._parent._lib_root, "schemas", filename)) as f:
 				self._schemas[splitext(filename)[0]] = json.loads(f.read())
 
 	async def register(self, recapcha: str, email: str, password: str, send_mail: bool = True, giftkey: Optional[str] = None) -> bool:
@@ -84,8 +84,6 @@ class High_Level:
 
 		# TODO: check if keystore is actually valid b64 ?
 
-		print(json.dumps(keystore))
-
 		keystore = json.loads(b64decode(keystore["keystore"]).decode())
 		validate(keystore, self._schemas["schema_keystore_encrypted"])
 
@@ -94,13 +92,12 @@ class High_Level:
 		sdata = bytes(keystore["sdata"])
 
 		data = decrypt_data(sdata, key, nonce)
-		print(data)
 		json_data = json.loads(data)
 		validate(json_data, self._schemas["schema_keystore_decrypted"])
 
 		keys = json_data["keys"]
-		for key in keys:
-			keys[key] = bytes(keys[key])
+		for meta in keys:
+			keys[meta] = bytes(keys[meta])
 
 		# here, the data should be all valid. Still possible to be false (while valid),
 		# but it would be incredibly rare
@@ -123,11 +120,10 @@ class High_Level:
 			del keystore["nonce"]
 
 			keys = keystore["keys"]
-			for key in keys:
-				keys[key] = list(keys[key])
+			for meta in keys:
+				keys[meta] = list(keys[meta])
 
-			json_data = json.dumps(keystore)
-			print(json_data)
+			json_data = json.dumps(keystore, separators = (',', ':'))
 			encrypted_data = encrypt_data(json_data, key, nonce)
 
 			keystore = {
@@ -136,11 +132,7 @@ class High_Level:
 				"sdata": list(encrypted_data)
 			}
 
-			print(json.dumps(keystore))
-
-			keystore = { "keystore": b64encode(json.dumps(keystore)).decode() }
-
-			raise NotImplementedError("This method has not been tested and shouldn't be used. You have been warned")
+			keystore = { "keystore": b64encode(json.dumps(keystore, separators = (',', ':')).encode()).decode() }
 
 		return await self._parent.low_level.set_keystore(keystore)
 
